Geom Quadrant Text
geom_quad_txt(he, graph_params)A bcea object containing the results of the Bayesian
modelling and the economic evaluation.
A string used to select the graphical engine to use for
plotting. Should (partial-)match the three options "base",
"ggplot2" or "plotly". Default value is "base".
Not all plotting functions have a "plotly" implementation yet.