This data set contains the results of the Bayesian analysis used to model the clinical output and the costs associated with the health economic evaluation of four different smoking cessation interventions.
data(Smoking)A data list including the variables needed for the smoking cessation cost-effectiveness analysis. The variables are as follows:
ca matrix of 500 simulations from the posterior distribution of the overall costs associated with the four strategies
dataa dataset containing the characteristics of the smokers in the UK population
ea matrix of 500 simulations from the posterior distribution of the clinical benefits associated with the four strategies
life.yearsa matrix of 500 simulations from the posterior distribution of the life years gained with each strategy
pia matrix of 500 simulations from the posterior distribution of the event of smoking cessation with each strategy
smokinga data frame containing the inputs needed for the network
meta-analysis model. The data.frame object contains: nobs: the record
ID number, s: the study ID number, i: the intervention ID number,
r_i: the number of patients who quit smoking, n_i: the total number of
patients for the row-specific arm and b_i: the reference intervention for
each study
smoking_outputa rjags object obtained by running the
network meta-analysis model based on the data contained in the smoking object
smoking_mata matrix obtained by running the
network meta-analysis model based on the data contained in the smoking object
treatsa vector of labels associated with the four strategies
Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman Hall, London
# NOT RUN {
data(Smoking)
# }
# NOT RUN {
m=bcea(e,c,ref=4,interventions=treats,Kmax=500)
# }
Run the code above in your browser using DataLab