This data set contains the results of the Bayesian analysis used to model the clinical output and the costs associated with an influenza vaccination.
data(Vaccine)A data list including the variables needed for the influenza vaccination. The variables are as follows:
ca matrix of simulations from the posterior distribution of the overall costs associated with the two treatments
cost.GPa matrix of simulations from the posterior distribution of the costs for GP visits associated with the two treatments
cost.hospa matrix of simulations from the posterior distribution of the costs for hospitalisations associated with the two treatments
cost.otca matrix of simulations from the posterior distribution of the costs for over-the-counter medications associated with the two treatments
cost.time.offa matrix of simulations from the posterior distribution of the costs for time off work associated with the two treatments
cost.time.vaca matrix of simulations from the posterior distribution of the costs for time needed to get the vaccination associated with the two treatments
cost.travela matrix of simulations from the posterior distribution of the costs for travel to get vaccination associated with the two treatments
cost.trt1a matrix of simulations from the posterior distribution of the overall costs for first line of treatment associated with the two interventions
cost.trt2a matrix of simulations from the posterior distribution of the overall costs for second line of treatment associated with the two interventions
cost.vaca matrix of simulations from the posterior distribution of the costs for vaccination
c.ptsa matrix of simulations from the posterior distribution of the clinical benefits associated with the two treatments
ea matrix of simulations from the posterior distribution of the clinical benefits associated with the two treatments
e.ptsa matrix of simulations from the posterior distribution of the clinical benefits associated with the two treatments
Nthe number of subjects in the reference population
N.outcomesthe number of clinical outcomes analysed
N.resourcesthe number of health-care resources under study
QALYs.adva vector from the posterior distribution of the QALYs associated with advert events
QALYs.deatha vector from the posterior distribution of the QALYs associated with death
QALYs.hospa vector from the posterior distribution of the QALYs associated with hospitalisation
QALYs.infa vector from the posterior distribution of the QALYs associated with influenza infection
QALYs.pnea vector from the posterior distribution of the QALYs associated with penumonia
treatsa vector of labels associated with the two treatments
vaccinea rjags object containing the simulations for the parameters
used in the original model
vaccine_mata matrix containing the simulations for the parameters used in the original model
Baio, G., Dawid, A. P. (2011). Probabilistic Sensitivity Analysis in Health Economics. Statistical Methods in Medical Research doi:10.1177/0962280211419832.
# NOT RUN {
data(Vaccine)
# }
# NOT RUN {
m=bcea(e,c,ref=1,interventions=treats)
# }
Run the code above in your browser using DataLab