bcea## S3 method for class 'bcea':
contour(x, comparison = 1, scale = 0.5, nlevels = 4, levels = NULL,
pos = c(1,0), graph=c("base","ggplot2"), ...)bcea object containing the results of the Bayesian modelling and the economic evaluationgraph="ggplot2" any subset of the possible comparisons can be selected, and graph="ggplot2".(bottom|top)(right|left) for base graphics and bottom, top, left or right for ggplot2. It can be a two-elements "base" or "ggplot2". Default value is "base".graph="ggplot2".graph="ggplot2".Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman Hall, London
bcea,
ceplane.plot,
contour2