bcea
"contour"(x, comparison = 1, scale = 0.5, nlevels = 4, levels = NULL, pos = c(1,0), xlim=NULL, ylim=NULL, graph=c("base","ggplot2"), ...)bcea object containing the results of the Bayesian modelling and the economic
evaluation
graph="ggplot2" any subset of the possible comparisons can be selected, and
comparison=NULL will yield a plot of all the possible comparisons together.
graph="ggplot2".
(bottom|top)(right|left) for base graphics and bottom, top,
left or right for ggplot2. It can be a two-elements vector, which
specifies the relative position on the x and y axis respectively, or alternatively it
can be in form of a logical variable, with FALSE indicating to use the default
position and TRUE to place the legend on the bottom of the plot. Default value is
c(1,0), that is the bottomright corner inside the plot area.
"base" or "ggplot2". Default value is "base".
delta.edelta.cgraph="ggplot2".
graph="ggplot2".
Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman Hall, London
bcea,
ceplane.plot,
contour2