Performs diagnostic plots for the results of the multiparameter EVPPI
Usage
diag.evppi(x, k = NULL, t = 1, diag = c("residuals", "qqplot", "bias", "se"))
Arguments
x
An evppi object containing the results of the multiparameter computations
k
The value of the willingness to pay selected for the analysis. If the diagnostics selected is either residual or qqplot, then it needs to be specified. If it is either bias or se plot, it is not relevant
t
The intervention selected for the analysis. If it is left unspecified, the default value 1 for the first intervention will be used
diag
A text string specifying the diagnostics to be performed. The default value is 'residuals'. Other possibilities are 'qqplot', 'bias' and 'se'
References
Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman Hall, London